Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2387)

Unified Diff: content/renderer/input_tag_speech_dispatcher.h

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/speech_recognition_result.cc ('k') | content/renderer/input_tag_speech_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/input_tag_speech_dispatcher.h
diff --git a/content/renderer/speech_input_dispatcher.h b/content/renderer/input_tag_speech_dispatcher.h
similarity index 58%
rename from content/renderer/speech_input_dispatcher.h
rename to content/renderer/input_tag_speech_dispatcher.h
index 174dd6a1e4c1625f90610f5bc4f7516634eed0f9..dca92ab1d44b2ff0f2bdab6e369059fe62255f6c 100644
--- a/content/renderer/speech_input_dispatcher.h
+++ b/content/renderer/input_tag_speech_dispatcher.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_RENDERER_SPEECH_INPUT_DISPATCHER_H_
-#define CONTENT_RENDERER_SPEECH_INPUT_DISPATCHER_H_
+#ifndef CONTENT_RENDERER_INPUT_TAG_SPEECH_DISPATCHER_H_
+#define CONTENT_RENDERER_INPUT_TAG_SPEECH_DISPATCHER_H_
#include "base/basictypes.h"
#include "content/public/renderer/render_view_observer.h"
@@ -12,20 +12,20 @@
class RenderViewImpl;
namespace content {
-struct SpeechInputResult;
+struct SpeechRecognitionResult;
}
namespace WebKit {
class WebSpeechInputListener;
}
-// SpeechInputDispatcher is a delegate for speech input messages used by WebKit.
-// It's the complement of SpeechInputDispatcherHost (owned by RenderViewHost).
-class SpeechInputDispatcher : public content::RenderViewObserver,
- public WebKit::WebSpeechInputController {
+// InputTagSpeechDispatcher is a delegate for messages used by WebKit. It's
+// the complement of InputTagSpeechDispatcherHost (owned by RenderViewHost).
+class InputTagSpeechDispatcher : public content::RenderViewObserver,
+ public WebKit::WebSpeechInputController {
public:
- SpeechInputDispatcher(RenderViewImpl* render_view,
- WebKit::WebSpeechInputListener* listener);
+ InputTagSpeechDispatcher(RenderViewImpl* render_view,
+ WebKit::WebSpeechInputListener* listener);
private:
// RenderView::Observer implementation.
@@ -41,15 +41,15 @@ class SpeechInputDispatcher : public content::RenderViewObserver,
virtual void cancelRecognition(int request_id);
virtual void stopRecording(int request_id);
- void OnSpeechRecognitionResult(int request_id,
- const content::SpeechInputResult& result);
+ void OnSpeechRecognitionResult(
+ int request_id, const content::SpeechRecognitionResult& result);
void OnSpeechRecordingComplete(int request_id);
void OnSpeechRecognitionComplete(int request_id);
void OnSpeechRecognitionToggleSpeechInput();
WebKit::WebSpeechInputListener* listener_;
- DISALLOW_COPY_AND_ASSIGN(SpeechInputDispatcher);
+ DISALLOW_COPY_AND_ASSIGN(InputTagSpeechDispatcher);
};
-#endif // CHROME_RENDERER_SPEECH_INPUT_DISPATCHER_H_
+#endif // CONTENT_RENDERER_INPUT_TAG_SPEECH_DISPATCHER_H_
« no previous file with comments | « content/public/common/speech_recognition_result.cc ('k') | content/renderer/input_tag_speech_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698